@@ -3,7 +3,7 @@
 // SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
 // SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 
-#include "notificationgroupingmodel.h"
+#include "notification/notificationgroupingmodel.h"
 
 NotificationGroupingModel::NotificationGroupingModel(QObject *parent)
     : QAbstractProxyModel(parent)
