@@ -4,10 +4,12 @@
 
 #pragma once
 
-#include "abstracttimelinemodel.h"
+#include "timeline/abstracttimelinemodel.h"
 
-/// Model for the notifications page
-/// \see AbstractTimelineModel
+/**
+ * @brief Model for the notifications page.
+ * @see AbstractTimelineModel
+ */
 class NotificationModel : public AbstractTimelineModel
 {
     Q_OBJECT
@@ -30,37 +32,58 @@ public:
     /// \see setExcludesTypes
     QStringList excludeTypes() const;
 
-    /// Set the types of notifications to exclude
-    /// Valid options are "mention", "status", "reblog", "follow", "follow_request", "favourite", "poll" and "update"
-    /// \see excludeTypes
+    /**
+     * @brief Set the types of notifications to exclude.
+     *
+     * Valid options are "mention", "status", "reblog", "follow", "follow_request", "favourite", "poll" and "update".
+     *
+     * @see excludeTypes()
+     */
     void setExcludesTypes(const QStringList &excludeTypes);
 
 public Q_SLOTS:
-    /// Reply to the notification at \p index
-    /// \see wantReply
+    /**
+     * @brief Reply to the notification at @p index.
+     * @see wantReply()
+     */
     void actionReply(const QModelIndex &index);
 
-    /// Favorite the notification at \p index
+    /**
+     * @brief Favorite the notification at @p index.
+     */
     void actionFavorite(const QModelIndex &index);
 
-    /// Boost the notification at \p index
+    /**
+     * @brief Boost the notification at @p index.
+     */
     void actionRepeat(const QModelIndex &index);
 
-    /// Delete and re-draft the notification at \p index
-    /// \see postSourceReady
+    /**
+     * @brief Delete and re-draft the notification at @p index.
+     * @see postSourceReady()
+     */
     void actionRedraft(const QModelIndex &index, bool isEdit);
 
-    /// Delete the notification at \p index
+    /**
+     * @brief Delete the notification at @p index.
+     */
     void actionDelete(const QModelIndex &index);
 
-    /// Bookmark the notification at \p index
+    /**
+     * @brief Bookmark the notification at @p index.
+     */
     void actionBookmark(const QModelIndex &index);
+
 Q_SIGNALS:
-    /// Emitted when the list of excluded notification types change
-    /// \see setExcludesTypes
+    /**
+     * @brief Emitted when the list of excluded notification types change
+     * @see setExcludesTypes()
+     */
     void excludeTypesChanged();
 
-    /// Emitted when actionReply is called
+    /**
+     * @brief Emitted when actionReply is called.
+     */
     void wantReply(AbstractAccount *account, Post *post, const QModelIndex &index);
 
 protected:
